@@ -1,5 +1,5 @@
 package Sys::Info::Driver::OSX::Device;
-$Sys::Info::Driver::OSX::Device::VERSION = '0.7959';
+$Sys::Info::Driver::OSX::Device::VERSION = '0.7960';
 use strict;
 use warnings;
 
@@ -17,11 +17,11 @@ Sys::Info::Driver::OSX::Device
 
 =head1 VERSION
 
-version 0.7959
+version 0.7960
 
 =head1 SYNOPSIS
 
-    use base qw( Sys::Info::Driver::OSX::Device );
+    use parent qw( Sys::Info::Driver::OSX::Device );
 
 =head1 DESCRIPTION
 
